@@ -21,7 +21,7 @@
 
 from cobra import Model, Reaction
 from typing import TYPE_CHECKING, Dict, Iterable, List, Optional, Tuple, Union
-from kdfba.reactions import dReaction
+from dfba.reactions import dReaction
 from warnings import warn
 import re
 
@@ -47,7 +47,7 @@ class dModel(Model):
             return True
         else:
             return False
-    
+
     def __is_right_objective(self, sub_objective):
         if sub_objective in self.reactions:
             return True
@@ -56,7 +56,7 @@ class dModel(Model):
 
     # FVA目标设置
     def change_objective(
-            self, 
+            self,
             main_objective: str,  ## 主要优化目标
             main_objective_direction: str,  ## 主要优化目标优化方向
             sub_objectives: List = None,  ## 次级优化目标（Reaction类型列表，包含多个反应  # 12.18补充，元素既可为反应也可为字符串）
@@ -172,7 +172,7 @@ class dModel(Model):
 
         matchObj1_weight = re.search(pat, weight)
         matchObj2_weight = re.match(pat_float, weight)
-        if matchObj1_weight or matchObj2_weight():
+        if matchObj1_weight or matchObj2_weight:
             self.weight = weight
         else:
             raise ValueError(f"'{weight}'并非符合规范的科学计数法, 请参照'1e-15'形式输入.")
