@@ -212,8 +212,8 @@ class solver():
                         if item_temp in reactions.keys():
                             exec('var[item] =' + model_weight + '*' + item_temp)
                         else:
-                            print(model_name)
-                            print(flux_name)
+                            # print(model_name)
+                            # print(flux_name)
                             flux = var[model_name + '_solution'].fluxes['%s' % flux_name]
                             exec('var[item] =' + model_weight + '* flux')
                 exec("derivative['d']=" + derivative_description)
